@@ -3,7 +3,7 @@
 import contextlib
 import typing as t
 
-from flask_gordon.ext import ArgParse as ArgParseExt
+from flask_gordon.ext import ArgParseExt
 from torxtools.ctxtools import suppress_traceback
 
 from . import app, rootpath
