@@ -1,7 +1,7 @@
 import gitlab as GitLab
 
 
-def gitlab(app):
-    cfg = app.settings["gitlab"]
+def gitlab(settings):
+    cfg = settings["gitlab"]
     gl = GitLab.Gitlab(cfg["url"], private_token=cfg["token"])
     return gl
